@@ -10,20 +10,29 @@ from datadog.api.resources import (
     ListableAPIResource,
     ListableAPISubResource,
     UpdatableAPIResource,
-    UpdatableAPISubResource
+    UpdatableAPISubResource,
 )
 
 from datadog.api.dashboard_list_v2 import DashboardListV2
 
 
-class DashboardList(AddableAPISubResource, CreateableAPIResource, DeletableAPIResource,
-                    DeletableAPISubResource, GetableAPIResource, ListableAPIResource,
-                    ListableAPISubResource, UpdatableAPIResource, UpdatableAPISubResource):
+class DashboardList(
+    AddableAPISubResource,
+    CreateableAPIResource,
+    DeletableAPIResource,
+    DeletableAPISubResource,
+    GetableAPIResource,
+    ListableAPIResource,
+    ListableAPISubResource,
+    UpdatableAPIResource,
+    UpdatableAPISubResource,
+):
     """
     A wrapper around Dashboard List HTTP API.
     """
-    _resource_name = 'dashboard/lists/manual'
-    _sub_resource_name = 'dashboards'
+
+    _resource_name = "dashboard/lists/manual"
+    _sub_resource_name = "dashboards"
 
     # Support for new API version (api.DashboardList.v2)
     # Note: This needs to be removed after complete migration of these endpoints from v1 to v2.
