@@ -6,16 +6,16 @@
 """
 DogStatsd is a Python client for DogStatsd, a Statsd fork for Datadog.
 """
-# stdlib
+# Standard libraries
 from random import random
 import logging
 import os
 import socket
 import errno
 import time
-from threading import Lock
+from threading import Lock, RLock
 
-# datadog
+# Datadog libraries
 from datadog.dogstatsd.context import (
     TimedContextManagerDecorator,
     DistributedContextManagerDecorator,
@@ -51,6 +51,21 @@ DD_ENV_TAGS_MAPPING = {
 # Telemetry minimum flush interval in seconds
 DEFAULT_TELEMETRY_MIN_FLUSH_INTERVAL = 10
 
+# Telemetry pre-computed formatting string. Pre-computation
+# increases throughput of composing the result by 2-15% from basic
+# '%'-based formatting with a `join`.
+TELEMETRY_FORMATTING_STR = "\n".join(
+    [
+        "datadog.dogstatsd.client.metrics:%s|c|#%s",
+        "datadog.dogstatsd.client.events:%s|c|#%s",
+        "datadog.dogstatsd.client.service_checks:%s|c|#%s",
+        "datadog.dogstatsd.client.bytes_sent:%s|c|#%s",
+        "datadog.dogstatsd.client.bytes_dropped:%s|c|#%s",
+        "datadog.dogstatsd.client.packets_sent:%s|c|#%s",
+        "datadog.dogstatsd.client.packets_dropped:%s|c|#%s",
+    ]
+)
+
 
 class DogStatsd(object):
     OK, WARNING, CRITICAL, UNKNOWN = (0, 1, 2, 3)
@@ -170,7 +185,7 @@ class DogStatsd(object):
         :type telemetry_socket_path: string
         """
 
-        self.lock = Lock()
+        self._socket_lock = Lock()
 
         # Check for deprecated option
         if max_buffer_size is not None:
@@ -260,6 +275,8 @@ class DogStatsd(object):
         self._telemetry_flush_interval = telemetry_min_flush_interval
         self._telemetry = not disable_telemetry
 
+        self._buffer_lock = RLock()
+
     def disable_telemetry(self):
         self._telemetry = False
 
@@ -298,7 +315,7 @@ class DogStatsd(object):
         Note: connect the socket before assigning it to the class instance to
         avoid bad thread race conditions.
         """
-        with self.lock:
+        with self._socket_lock:
             if telemetry and self._dedicated_telemetry_destination():
                 if not self.telemetry_socket:
                     if self.telemetry_socket_path is not None:
@@ -339,7 +356,12 @@ class DogStatsd(object):
         >>> with DogStatsd() as batch:
         >>>     batch.gauge("users.online", 123)
         >>>     batch.gauge("active.connections", 1001)
+
+        Note: This method must be called before close_buffer() matching invocation.
         """
+
+        self._buffer_lock.acquire()
+
         if max_buffer_size is not None:
             log.warning("The parameter max_buffer_size is now deprecated and is not used anymore")
         self._current_buffer_total_size = 0
@@ -349,12 +371,22 @@ class DogStatsd(object):
     def close_buffer(self):
         """
         Flush the buffer and switch back to single metric packets.
-        """
-        self._send = self._send_to_server
 
-        if self.buffer:
-            # Only send packets if there are packets to send
-            self._flush_buffer()
+        Note: This method must be called after a matching open_buffer()
+        invocation.
+        """
+
+        if not hasattr(self, "buffer"):
+            raise BufferError("Cannot close buffer that was never opened")
+
+        try:
+            self._send = self._send_to_server
+
+            if self.buffer:
+                # Only send packets if there are packets to send
+                self._flush_buffer()
+        finally:
+            self._buffer_lock.release()
 
     def gauge(
         self,
@@ -493,7 +525,7 @@ class DogStatsd(object):
         """
         Closes connected socket if connected.
         """
-        with self.lock:
+        with self._socket_lock:
             if self.socket:
                 try:
                     self.socket.close()
@@ -559,16 +591,22 @@ class DogStatsd(object):
 
     def _flush_telemetry(self):
         telemetry_tags = ",".join(self._add_constant_tags(self._client_tags))
-        return "\n".join(
-            (
-                "datadog.dogstatsd.client.metrics:%s|c|#%s" % (self.metrics_count, telemetry_tags),
-                "datadog.dogstatsd.client.events:%s|c|#%s" % (self.events_count, telemetry_tags),
-                "datadog.dogstatsd.client.service_checks:%s|c|#%s" % (self.service_checks_count, telemetry_tags),
-                "datadog.dogstatsd.client.bytes_sent:%s|c|#%s" % (self.bytes_sent, telemetry_tags),
-                "datadog.dogstatsd.client.bytes_dropped:%s|c|#%s" % (self.bytes_dropped, telemetry_tags),
-                "datadog.dogstatsd.client.packets_sent:%s|c|#%s" % (self.packets_sent, telemetry_tags),
-                "datadog.dogstatsd.client.packets_dropped:%s|c|#%s" % (self.packets_dropped, telemetry_tags),
-            )
+
+        return TELEMETRY_FORMATTING_STR % (
+            self.metrics_count,
+            telemetry_tags,
+            self.events_count,
+            telemetry_tags,
+            self.service_checks_count,
+            telemetry_tags,
+            self.bytes_sent,
+            telemetry_tags,
+            self.bytes_dropped,
+            telemetry_tags,
+            self.packets_sent,
+            telemetry_tags,
+            self.packets_dropped,
+            telemetry_tags,
         )
 
     def _is_telemetry_flush_time(self):
