@@ -17,8 +17,8 @@ from mock import patch
 
 # datadog
 from datadog import ThreadStats, lambda_metric, datadog_lambda_wrapper
-from datadog.threadstats.aws_lambda import _lambda_stats
-from tests.util.contextmanagers import preserve_environment_variable
+from datadog.threadstats.aws_lambda import _get_lambda_stats
+from tests.util.contextmanagers import preserve_environment_variable, EnvVars
 
 # Silence the logger.
 logger = logging.getLogger('dd.datadogpy')
@@ -772,6 +772,31 @@ class TestUnitThreadStats(unittest.TestCase):
         assert event['tags'] == [event1_tag] + constant_tags + test_tags
         dog.start(flush_interval=1, roll_up_interval=1)
 
+    def test_tags_from_environment_env_service_version(self):
+        test_tags = set(['env:staging', 'service:food', 'version:1.2.3'])
+        with EnvVars(
+            env_vars={
+                "DD_ENV": "staging",
+                "DD_VERSION": "1.2.3",
+                "DD_SERVICE": "food",
+            }
+        ):
+            dog = ThreadStats()
+        dog.start(roll_up_interval=10, flush_in_thread=False)
+        reporter = dog.reporter = MemoryReporter()
+
+        # Add two events
+        event1_title = "Event 1 title"
+        event1_text = "Event 1 text"
+        dog.event(event1_title, event1_text)
+
+        # Flush and test
+        dog.flush()
+        [event1] = reporter.events
+        assert event1['title'] == event1_title
+        assert event1['text'] == event1_text
+        assert set(event1['tags']) == test_tags
+
     def test_metric_type(self):
         """
         Checks the submitted metric's metric type.
@@ -808,11 +833,11 @@ class TestUnitThreadStats(unittest.TestCase):
         def basic_wrapped_function():
             lambda_metric("lambda.somemetric", 100)
 
-        _lambda_stats.reporter = self.reporter
+        _get_lambda_stats().reporter = self.reporter
         basic_wrapped_function()
 
-        assert _lambda_stats.reporter.dist_flush_counter == 1
-        dists = self.sort_metrics(_lambda_stats.reporter.distributions)
+        assert _get_lambda_stats().reporter.dist_flush_counter == 1
+        dists = self.sort_metrics(_get_lambda_stats().reporter.distributions)
         assert len(dists) == 1
 
     def test_embedded_lambda_decorator(self):
@@ -829,9 +854,9 @@ class TestUnitThreadStats(unittest.TestCase):
             wrapped_function_1()
             lambda_metric("lambda.dist.2", 30)
 
-        _lambda_stats.reporter = self.reporter
+        _get_lambda_stats().reporter = self.reporter
         wrapped_function_2()
-        assert _lambda_stats.reporter.dist_flush_counter == 1
+        assert _get_lambda_stats().reporter.dist_flush_counter == 1
 
-        dists = self.sort_metrics(_lambda_stats.reporter.distributions)
+        dists = self.sort_metrics(_get_lambda_stats().reporter.distributions)
         assert len(dists) == 2
